( cd opt/kde/share/doc/HTML/sv/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ark ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kig ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/juk ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/juk ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ktuberling ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/amor ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/karm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kate ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdat ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdvi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kget ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kget ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kgpg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmag ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmid ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmix ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kodo ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kolf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpat ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpdf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/korn ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kppp ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/krdc ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/krdc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/krec ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/krfb ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kscd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksim ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/lisa ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kxkb ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kalzium ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/katomic ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksysguard ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kbounce ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdearch ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdearch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdelirc/kcmlirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdelirc/irkick ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kbattleship ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kaboodle ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/knewsticker ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/knewsticker ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khangman ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kfloppy ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/cervisia ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khexedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khexedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpercentage ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kandy ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcalc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdcop ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdcop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdesu ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcron ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdict ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kfind ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kiten ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kiten ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kjots ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kjots ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmail ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmidi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmidi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmoon ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/knode ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kooka ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksame ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksirc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ktnef ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ktnef ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksysv ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ktron ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kttsd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kttsd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kuser ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kview ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kwin4 ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/lskat ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/klipper ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmousetool ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kompare ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kompmgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kompmgr ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kontact ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konsole ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konsolekalendar ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kanagram ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kanagram ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpackage ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/lilo-config ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/lilo-config ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kshisen ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksirtet ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdesvn-build ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdesvn-build ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konquest ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/akregator ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/akregator ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kturtle ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kturtle ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kverbos ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kwallet ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kweather ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kioslave ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/knetattach ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/knetattach ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kxconfig ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kxconfig ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/multisynk ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/multisynk ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/performance ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcontrol/performance ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/artsbuilder ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/crashes ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/babel ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/kuick ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/webarchiver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/domtreeviewer ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/imgallery ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/khtmlsettings ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/validators ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/fsview ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/uachanger ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/mediaplayer ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/dirfilter ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kbabel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kalarm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kamera ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kaudiocreator ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kaudiocreator ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdeprint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kasteroids ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kbruch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/keduca ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kgamma ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdevelop ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdevelop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kicker ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/klatin ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/klatin ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/klines ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmines ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmouth ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmplot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/knotes ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kopete ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpilot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpoker ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kruler ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ktalkd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksnake ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kspell ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kstars ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ktimer ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ktouch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kwrite ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/megami ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/megami ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kreversi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/noatun ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksplashml ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kblackbox ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kcharselect ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/quanta ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/superkaramba ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/superkaramba ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksmiletris ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksmiletris ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kuickshow ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kolourpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kde_app_devel ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kommander ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kommander ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kiconedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kmahjongg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/klettres ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/xsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/xsldbg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kghostview ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/klickety ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kfilereplace ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kgeography ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kgeography ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kleopatra ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kenolaba ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kworldclock ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/blinken ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/blinken ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/ksokoban ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kteatime ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/knetworkconf ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/cdinfo ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/cdinfo ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/opengl ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/umbrello ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/konqueror ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/kwordquiz ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/korganizer ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
( cd opt/kde/share/doc/HTML/sv/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/atlantik ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
